# Hintful Advancements

## Description

Advancements and the recipe book have done much to guide players into discovering Minecraft mechanics, yet many things remain nigh-unfindable within the game itself. Powering enchanting tables, activating conduits, marking banners on a map... how is a player (unaided by external sources) expected to discover such features?

This data pack fills in the blanks with several new advancements focused on features left obscure by the base game. Each advancement is carefully crafted to reveal new possibilities to the player, while not spoon-feeding them every detail. The goal is to encourage players to explore and experiment. In keeping with vanilla, the icon, title, and description of each advancement are deliberately chosen to concisely deliver both hints and humor.

Supports Minecraft Java Edition 1.20.3 through 1.21.2 (specifically 23w41a through 1.21.2 Pre-Release 1).

## Added Advancements

<details>
<summary>Advancement spoilers</summary>

### Minecraft

- 📚 "Multi-Book Structure" (level up enchanting table)

### Adventure

- ⚡ "Getting Ahead" (get a zombie head)
- ☃️ "Face Reveal" (shear a snow golem)
- 🤖 "Iron Supplements" (repair an iron golem)
- 🗺️ "Local Positioning System" (get a map)
- 🪪 "Persistent Mob" (name a mob)
- 📍 "Point of Interest" (mark a named banner on a map)
- 🖼️ "Who Framed Yonder Map-It?" (frame a map)
- ❌ "X Marks the Spot" (find buried treasure)
- 🫧 "You Con-du-it" (activate a conduit)

### Nether

- 🛏️ "Beds Away!" (sleep in the Nether)
- ❤️ "Kill 'Em with Kindness" (attack the undead with healing potions)
- 🌋 "Spice Cube" (get a froglight)

### The End

- 🎃 "Frienderman" (look at enderman without triggering it)
- 🚀 "Rocket Science" (fly via elytra above the highest blocks)

</details>

## Explanation of Implementation

<details>
<summary>Advancement spoilers</summary>

"Local Positioning System" exists primarily to allow several other advancements to be grouped under it, rather than be scattered across the top level of the Adventure tab.

I limited "Getting Ahead" to zombie heads for 2 reasons:

- Skeleton skulls are obtainable in ancient cities, and wither skeleton skulls are obtainable as a standard mob drop. I currently have no (practical) way of determining how a player obtained a skull.
- Including zombies, creepers, and piglins, but not skeletons feels weird, so I figured I should pick just one. I chose zombies since they're common, slow-moving, and demonstrate the mechanic most clearly.

I chose not to use the `is_flying` flag in "Rocket Science" because I want to specifically target elytra flight and ignore creative mode flight. The `FallFlying` NBT tag remains the most foolproof way to accomplish this. (Mojang, please add `is_gliding`.)

I also intentionally do not check for firework usage in "Rocket Science", so that a player may also obtain the advancement through more creative (and less obvious) means e.g. TNT launchers.

</details>

## Bugs, Suggestions, and Feedback

Found a bug? Have an idea to improve the pack? Let me know by opening an issue on the [GitLab](https://gitlab.com/ZebulanStanphill/hintful-advancements/-/issues).

## Credits

### Advancement Titles, Descriptions, and Ideas

"Point of Interest": Banner pattern yoinked from [Lime's Advancements](https://github.com/slicedlime/LimesAdvancements/) by [slicedlime](https://www.youtube.com/slicedlime). (Funnily enough, I actually independently came up with the same advancement title as slicedlime before discovering his pack. I was originally using a plain blue banner for the icon, and much to my surprise, the base color of the banner in slicedlime's pack is also blue.)

"Who Framed Yonder Map-It?": Inspired by "Map Wall" from Lime's Advancements, but now it has a funnier name.

"X Marks the Spot": Title taken from Lime's Advancements, and the description is derived from the description of the "Bad Sailors" advancement in that pack.

"You Con-du-it": Title taken from Lime's Advancements.

"Face Reveal": Title taken from similar advancement in Lime's Advancements. My pack intentionally lacks an equivalent to the preceding "Snowball Fight" advancement from slicedlime's pack, since I prefer to convey more info with fewer advancements.

"Getting Ahead": Title taken from Lime's Advancements. "Mind-Blowing" was my initial idea, but slicedlime's pun seemed superior.

### Other

Ray-casting logic based on [Simple Raycasting Engine/Framework](https://www.planetminecraft.com/data-pack/raycasting-engine-framework/) by [itskegnh](https://www.planetminecraft.com/member/itskegnh/).

Shout out to PiroPito, whose [blind playthrough of Minecraft](https://www.youtube.com/playlist?list=PLbqkLu2V1bJJUQ2aLZjFdz8decGs1kHg-) was a big inspiration for making this pack.

And of course, a very special thanks to the Lord God, without whom none of this would have been possible.

## License

I'm not even sure if the contents of this data pack are copyrightable, but insofar as they are, see `LICENSE.txt`.
